================
Pics
================

Game of life
=================

Did you know?

Pulsar is the fourth most common oscillator in the game of life.

.. image:: http://www.conwaylife.com/w/images/e/ef/Pulsar.gif
   :width: 100


Python Powered
=================

Pulsar loves python as much as the minion in the image!

.. image:: https://lh5.googleusercontent.com/-xVSvSecp6kE/Uk3XDSCCHVI/AAAAAAAABIs/r1rnKMHbT_w/w1560-h878-no
   :width: 500


Logos
=======

Pulsar needs a logo, can you design one for us?

Logo 1
~~~~~~~~~~

.. image:: _static/pulsar.png
   :width: 300 px


Logo 2
~~~~~~~~~~

.. image:: _static/pulsar2.png
   :width: 300 px

Logo 3
~~~~~~~~~~

Inspired from one of the pulsar oscillator images

.. image:: _static/pulsar3.png
   :width: 300 px
